package dao;

import dao.database_vero.HsqldbDAOFactory;
import dao.prototipo_rapido.PocoTempoDAOFactory;

public abstract class DAOFactory {

	
	
	// --- List of supported DAO types ---
	
	/**
	 * Numeric constant '1' corresponds to Hsqldb choice
	 */
	public static final int HSQLDB = 1;

	/**
	 * Numeric constant '2' corresponds to poco-tempo choice
	 */
	public static final int PROTOTIPO = 2;

	
	
	// --- Actual factory method ---
	
	/**
	 * Depending on the input parameter
	 * this method returns one out of several possible 
	 * implementations of this factory spec
	 */
	public static DAOFactory getDAOFactory(int whichFactory) {
		switch ( whichFactory ) {
		case HSQLDB:
			return new HsqldbDAOFactory();
		case PROTOTIPO:
			return new PocoTempoDAOFactory();
		default:
			return null;
		}
	}
	
	
	
	// --- Factory specification: concrete factories implementing this spec must provide this methods! ---

	public abstract PostDAO getPostDAO();

}
